<?php

namespace Drupal\aws_sns_entity_publish;

use Drupal\Core\Config\ConfigFactoryInterface;
use Aws\Sns\SnsClient;
use Drupal\Core\Messenger\MessengerTrait;

/**
 * Class AspServices to define Utility functions.
 *
 * @package Drupal\aws_sns_entity_publish\Services
 */
class AspServices {

  /**
   * The ConfigFactory for getting SNS configurations.
   *
   * @var Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  use MessengerTrait;

  /**
   * Constructs a new MostPopularArticle object.
   *
   * @param Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The Config Factory for accessing SNS configurations.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->configFactory = $configFactory;
  }

  /**
   * Function to push to AWS SNS.
   */
  public function entityPublishToAwsSns($subject, $message, $topic = '') {
    $messageGroupID = rand();
    $config = $this->configFactory->get('aws_sns_entity_publish.awsconfig');

    $params = [
      'credentials' => [
        'key' => $config->get('aws_sns_key'),
        'secret' => $config->get('aws_sns_secret'),
      ],
      'region' => $config->get('aws_sns_region'),
      'version' => $config->get('aws_sns_version'),
    ];
    $client = new SnsClient($params);

    $result = $client->publish([
      'TopicArn' => ($topic !== '') ? $topic : $config->get('aws_sns_default_topic_arn'),
      // Message is required.
      'Message' => $message,
      'MessageGroupId' => $messageGroupID,
      'Subject' => $subject,
      'MessageStructure' => 'aws sns notify',
    ]);

    $message_id = $result->search('MessageId');
    $this->messenger()->addStatus('AWS SNS message published. Msg id: ' . $message_id);
    return $message_id;
  }

}
